OiRA - Online διαδραστική Αξιολόγηση Κινδύνων

# Ορισμένες πληροφορίες για εσάς

Μπορείτε να παράσχετε τις πληροφορίες παρακάτω. Αυτές οι πληροφορίες προορίζονται για τη βελτίωση των παρεχόμενων εργαλείων και υπηρεσιών. Αυτά τα στοιχεία δεν εμφανίζονται στην αναφορά.

Η χώρα σας
Αριθμός υπαλλήλων 1 έως 9 υπάλληλοι 10 έως 49 υπάλληλοι 50 έως 249 υπάλληλοι 250 ή περισσότεροι υπάλληλοι
Η αξιολόγηση κινδύνου πραγματοποιήθηκε από προσωπικό εταιρείας εξωτερικός σύμβουλος ή πάροχος υπηρεσιών το προσωπικό της εταιρείας και εξωτερικός σύμβουλος ή πάροχος υπηρεσιών
Μέσω ποιου καναλιού μάθατε για αυτό το εργαλείο; οργανισμός ενός εργοδότη συνδικαλιστική οργάνωση δημόσιος οργανισμός/διοίκηση της χώρας
(Υπουργείο, Επιθεώρηση Εργασίας, Εθνικό Ινστιτούτο για την Υγεία και Ασφάλεια στην Εργασία, κ.λπ.) ευρωπαϊκός οργανισμός/διοίκηση
(Ευρωπαϊκός Οργανισμός για την Ασφάλεια και την Υγεία στην Εργασία, ευρωπαϊκοί κοινωνικοί εταίροι, κ.λπ.) ειδήμων υγείας και ασφάλειας άλλο κανάλι
Προσκλήθηκαν εργαζόμενοι για να μετάσχουν στην αξιολόγηση κινδύνου Ναι Όχι

1. Προετοιμασία
2. Αναγνώριση
3. Αξιολόγηση
4. Σχέδιο Δράσης
5. Αναφορά

Δημιουργήθηκε από EU-OSHA. | Σχετικά | Ιδιωτικότητα | Αποποίηση ευθυνών | Άδεια GPL |